AAudioStreamBuilder_setBufferCapacityInFrames

Function AAudioStreamBuilder_setBufferCapacityInFrames 

pub unsafe extern "C" fn AAudioStreamBuilder_setBufferCapacityInFrames(
    builder: *mut AAudioStreamBuilder,
    num_frames: i32,
)
Set the requested buffer capacity in frames. The final AAudioStream capacity may differ, but will probably be at least this big.

The default, if you do not call this function, is UNSPECIFIED.

Available since API level 26.

Arguments

  • builder - reference provided by AAudio_createStreamBuilder()
  • numFrames - the desired buffer capacity in frames or UNSPECIFIED