AAudioStream_getChannelCount

Function AAudioStream_getChannelCount 

pub unsafe extern "C" fn AAudioStream_getChannelCount(
    stream: *mut AAudioStream,
) -> i32
A stream has one or more channels of data. A frame will contain one sample for each channel.

Available since API level 26.

Arguments

  • stream - reference provided by AAudioStreamBuilder_openStream()