AAudioStream_getFramesPerDataCallback

Function AAudioStream_getFramesPerDataCallback 

pub unsafe extern "C" fn AAudioStream_getFramesPerDataCallback(
    stream: *mut AAudioStream,
) -> i32
Query the size of the buffer that will be passed to the dataProc callback in the numFrames parameter.

This call can be used if the application needs to know the value of numFrames before the stream is started. This is not normally necessary.

If a specific size was requested by calling AAudioStreamBuilder_setFramesPerDataCallback() then this will be the same size.

If AAudioStreamBuilder_setFramesPerDataCallback() was not called then this will return the size chosen by AAudio, or UNSPECIFIED.

UNSPECIFIED indicates that the callback buffer size for this stream may vary from one dataProc callback to the next.

Available since API level 26.

Arguments

  • stream - reference provided by AAudioStreamBuilder_openStream()