AAudioStream_getFramesRead

Function AAudioStream_getFramesRead 

pub unsafe extern "C" fn AAudioStream_getFramesRead(
    stream: *mut AAudioStream,
) -> i64
Passes back the number of frames that have been read since the stream was created. For an output stream, this will be advanced by the endpoint. For an input stream, this will be advanced by the application calling read() or by a data callback.

The frame position is monotonically increasing.

Available since API level 26.

Arguments

  • stream - reference provided by AAudioStreamBuilder_openStream()