AAudioStream_getFramesWritten

Function AAudioStream_getFramesWritten 

pub unsafe extern "C" fn AAudioStream_getFramesWritten(
    stream: *mut AAudioStream,
) -> i64
Passes back the number of frames that have been written since the stream was created. For an output stream, this will be advanced by the application calling write() or by a data callback. For an input stream, this will be advanced by the endpoint.

The frame position is monotonically increasing.

Available since API level 26.

Arguments

  • stream - reference provided by AAudioStreamBuilder_openStream()