AAudioStream_requestFlush

Function AAudioStream_requestFlush 

pub unsafe extern "C" fn AAudioStream_requestFlush(
    stream: *mut AAudioStream,
) -> i32
Asynchronous request for the stream to flush. Flushing will discard any pending data. This call only works if the stream is pausing or paused. Frame counters are not reset by a flush. They may be advanced. After this call the state will be in Flushing or Flushed.

Returns 0 for OK or a negative error.

This will return Unimplemented for input streams.

Available since API level 26.

Arguments

  • stream - reference provided by AAudioStreamBuilder_openStream()