AAudioStream_requestPause

Function AAudioStream_requestPause 

pub unsafe extern "C" fn AAudioStream_requestPause(
    stream: *mut AAudioStream,
) -> i32
Asynchronous request for the stream to pause. Pausing a stream will freeze the data flow but not flush any buffers. Use AAudioStream_requestStart() to resume playback after a pause. After this call the state will be in Pausing or Paused.

Returns 0 for OK or a negative error.

This will return Unimplemented for input streams. For input streams use AAudioStream_requestStop().

Available since API level 26.

Arguments

  • stream - reference provided by AAudioStreamBuilder_openStream()