pub unsafe extern "C" fn AAudioStreamBuilder_setDeviceId(
builder: *mut AAudioStreamBuilder,
device_id: i32,
)Expand description
Request an audio device identified device using an ID. On Android, for example, the ID could be obtained from the Java AudioManager.
The default, if you do not call this function, is UNSPECIFIED,
in which case the primary device will be used.
Available since API level 26.
Arguments
builder- reference provided by AAudio_createStreamBuilder()device_id- device identifier orUNSPECIFIED