pub unsafe extern "C" fn AAudioStream_close(
stream: *mut AAudioStream,
) -> i32Expand description
Delete the internal data structures associated with the stream created by AAudioStreamBuilder_openStream().
Returns 0 for OK or a negative error.
If AAudioStream_release() has not been called then it will be called automatically.
Arguments
stream- reference provided by AAudioStreamBuilder_openStream()