pub unsafe extern "C" fn AAudioStream_requestStart(
stream: *mut AAudioStream,
) -> i32Expand description
Asynchronously request to start playing the stream. For output streams, one should
write to the stream to fill the buffer before starting.
Otherwise it will underflow.
After this call the state will be in Starting or Started.
Returns 0 for OK or a negative error.
Available since API level 26.
Arguments
stream- reference provided by AAudioStreamBuilder_openStream()